--[[
-- Copyright 2016 AKA Russell
--
-- This file is part of Scarlet.
--
-- Scarlet is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- Scarlet is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Scarlet.  If not, see <http://www.gnu.org/licenses/>.
--]]

--[[
-- Contains a collection of functions for working with functions in the
-- context of Scarlet
--]]

local M = {}

function M.identity(...)
    return ...
end

--[[
-- Given an arbitrary number of functions, f1, f2, f3, ... fn composes them
-- into a single function f1 o f2 o f3 o ... o fn
-- where `o` is an ASCII approximation of the function composition operator.
---]]
function M.compose(...)
    if select("#", ...) == 0 then
        return M.identity
    else
        local f2tofn = M.compose(select(2, ...))
        local f1 = select(1, ...)
        return function(...) return f1(f2tofn(...)) end
    end
end

function M.truePredicate()
    return true
end

-- [[
-- The most recent version of Lua has moved unpack into table.unpack, but
-- Love still uses a version of unpack where unpack is a global function.
-- ]]
function M.unpack(...)
    return (unpack or table.unpack)(...)
end

return M
