--[[
-- Copyright 2017 AKA Russell
--
-- This file is part of Scarlet.
--
-- Scarlet is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- Scarlet is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Scarlet.  If not, see <http://www.gnu.org/licenses/>.
--]]
--
--[[
-- This module defines the atomic operations that are used as building blocks for defining
-- the operations that may be specified in the `do` block of a story event
--]]

local operations = {}

--[[
-- Changes the specified attribute on the specified character to the
-- specified value. For example `attribute(greg, gender, female)` will make `greg`
-- a woman.
--
-- character - The character whose attribute should be changed
-- attributename - The name of the attribute to be changed
-- value - The value to change the attribute to
--]]
function operations.attribute(character, attributename, newvalue)
    character.attributes[attributename] = newvalue
end

--[[
-- Sets the specified statistic on the specified character to the
-- specified value. For example `statistic(greg, hunger, 10)` sets `greg`'s
-- hunger statistic to 10.
--
-- character: The character whose statistic needs to be changed
-- statisticname: The name of the statistic to be modified
-- newvalue: The number to set the statistic to
--]]
function operations.statistic(character, statisticname, newvalue)
    character.statistics[statisticname] = newvalue
end

--[[
-- Adds the specified keyword to the player's set of acquired keywords.
--]]
function operations.keyword(keywords, newkeyword)
    keywords[newkeyword] = 1
end

return operations

